# Genyal: The cheerful genetic algorithm framework

![http://creativecommons.org/licenses/by/4.0/](https://i.creativecommons.org/l/by/4.0/88x31.png)

This work is licensed under a 
[Creative Commons Attribution 4.0 International License](http://creativecommons.org/licenses/by/4.0/)

<img src="resources/genyal-logo.png" alt="logo" height="200"/>

__Genyal__ is a genetic algorithm framework aimed to be as simple to use as it can be.
Evolution is natural, so using evolutionary algorithms should feel natural as well.

**Coming soon**
